==> bootstrap-styled-2.1.0.tgz: package/lib/utils/tests/index.test.js <==
'use strict';

var _color = require('color');

var _color2 = _interopRequireDefault(_color);

var _makeTheme = require('../../theme/makeTheme');

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('bootstrap-styled theme utils', function () {
  describe('makeScopedTheme', function () {
    it('should have makeScopedTheme defined', function () {
      expect(_index.makeScopedTheme).toBeDefined();
    });
    it('should have makeScopedTheme with a scoped theme', function () {
      var result = (0, _index.makeScopedTheme)('scopeName', { $white: 'pink' });
      expect(result).toEqual({ scopeName: result.scopeName });
    });
    it('should have makeScopedTheme with a scoped theme name as first argument', function () {
      expect((0, _index.makeScopedTheme)({})).toEqual(undefined);
      expect((0, _index.makeScopedTheme)({}, 'scopeName')).toEqual(undefined);
    });
  });
  describe('makeScopedTheme with calculus', function () {
    it('should have calculated scoped theme', function () {
      var makeDynamicTheme = function makeDynamicTheme() {
        var v = {};
        v.$white = 'pink';
        v.$blue = v.$white;
        v['$blue-darker'] = (0, _color2.default)(v.$blue).darken(0.05).toString();
        return v;
      };
      var theme = (0, _index.makeScopedTheme)('scopeName', makeDynamicTheme());
      var result = { $blue: 'pink', '$blue-darker': 'hsl(349.5, 100%, 83.3%)', $white: 'pink' };
      expect(theme.scopeName).toEqual(result);
      expect(theme.scopeName['$blue-darker']).toEqual(result['$blue-darker']);
    });
  });
  describe('createMakeTheme', function () {
    var themeListFunction = [(0, _index.toMakeTheme)((0, _makeTheme.makeTheme)({
      '$headings-font-family': '"Helvetica"'
    }))];
    var themeScopedListFunction = [(0, _index.toMakeTheme)((0, _makeTheme.makeTheme)({
      '$headings-font-family': '"Helvetica"'
    })), (0, _index.toMakeTheme)((0, _index.makeScopedTheme)('scopedTheme', {
      $color: 'blue'
    })), (0, _index.toMakeTheme)((0, _index.makeScopedTheme)('scopedThemeSecond', {
      '$bg-color': 'pink'
    }))];
    it('should have $headings-font-family equal to Helvetica', function () {
      var makeTheme = (0, _index2.default)(themeListFunction);
      expect(makeTheme()['$headings-font-family']).toBe('"Helvetica"');
    });

    it('should override $headings-font-family to equal Arial', function () {
      var makeTheme = (0, _index2.default)(themeListFunction);
      var modifiedTheme = makeTheme({
        '$headings-font-family': '"Arial"'
      });
      expect(modifiedTheme['$headings-font-family']).toBe('"Arial"');
    });
    it('should create a makeTheme based on a list of theme and scopedThemes', function () {
      var makeTheme = (0, _index2.default)(themeScopedListFunction);
      expect(makeTheme()['$headings-font-family']).toBe('"Helvetica"');
      expect(makeTheme().scopedTheme.$color).toBe('blue');
      expect(makeTheme().scopedThemeSecond['$bg-color']).toBe('pink');
    });
    it('should override theme and scoped theme variables', function () {
      var makeTheme = (0, _index2.default)(themeScopedListFunction);
      var modifiedTheme = makeTheme({
        '$headings-font-family': '"Arial"',
        scopedTheme: {
          $color: 'yellow'
        }
      });
      expect(modifiedTheme['$headings-font-family']).toBe('"Arial"');
      expect(modifiedTheme.scopedTheme.$color).toBe('yellow');
      expect(modifiedTheme.scopedThemeSecond['$bg-color']).not.toBe('orange');
    });
  });

  describe('toMakeTheme', function () {
    it('should treat theme like a NOT scoped theme', function () {
      var themeStartingWithVariable = { '$headings-font-family': 'Comic' };
      var makeThemeTestVariable = (0, _index.toMakeTheme)(themeStartingWithVariable);
      var themeStartingWithMetaData = { _name: 'name test' };
      var makeThemeTestMetaData = (0, _index.toMakeTheme)(themeStartingWithMetaData);
      expect(makeThemeTestVariable()['$headings-font-family']).toBe(themeStartingWithVariable['$headings-font-family']);
      expect(makeThemeTestMetaData()._name).toBe(themeStartingWithMetaData._name); // eslint-disable-line no-underscore-dangle
    });

    it('should create a makeTheme', function () {
      var theme = { '$headings-font-family': 'Comic' };
      var makeTheme = (0, _index.toMakeTheme)(theme);
      expect(makeTheme()['$headings-font-family']).toBe(theme['$headings-font-family']);
    });

    it('should override $headings-font-family variable to be equal to Arial', function () {
      var theme = { '$headings-font-family': 'Comic' };
      var makeThemeTest = (0, _index.toMakeTheme)(theme);
      var modifiedMakeThemeTest = makeThemeTest({
        '$headings-font-family': '"Arial"'
      });
      expect(modifiedMakeThemeTest['$headings-font-family']).toBe('"Arial"');
    });
    it('should create a makeTheme from a  scopedTheme', function () {
      var scopedTheme = { scopeName: { '$headings-font-family': 'Comic' } };
      var makeTheme = (0, _index.toMakeTheme)(scopedTheme);
      expect(makeTheme().scopeName['$headings-font-family']).toBe(scopedTheme.scopeName['$headings-font-family']);
    });

    it('should override $headings-font-family variable to be equal to Arial', function () {
      var scopedTheme = { scopeName: { '$headings-font-family': 'Comic' } };
      var makeTheme = (0, _index.toMakeTheme)(scopedTheme);
      var customTheme = makeTheme({
        scopeName: {
          '$headings-font-family': '"Arial"'
        }
      });
      expect(customTheme.scopeName['$headings-font-family']).toBe('"Arial"');
    });
  });
});

==> bootstrap-styled-2.1.1.tgz: package/lib/utils/tests/index.test.js <==
'use strict';

var _color = require('color');

var _color2 = _interopRequireDefault(_color);

var _theme = require('../../theme');

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('bootstrap-styled theme utils', function () {
  describe('makeScopedTheme', function () {
    it('should have makeScopedTheme defined', function () {
      expect(_index.makeScopedTheme).toBeDefined();
    });
    it('should have makeScopedTheme with a scoped theme', function () {
      var result = (0, _index.makeScopedTheme)('scopeName', { $white: 'pink' });
      expect(result).toEqual({ scopeName: result.scopeName });
    });
    it('should have makeScopedTheme with a scoped theme name as first argument', function () {
      expect((0, _index.makeScopedTheme)({})).toEqual(undefined);
      expect((0, _index.makeScopedTheme)({}, 'scopeName')).toEqual(undefined);
    });
  });
  describe('makeScopedTheme with calculus', function () {
    it('should have calculated scoped theme', function () {
      var makeDynamicTheme = function makeDynamicTheme() {
        var v = {};
        v.$white = 'pink';
        v.$blue = v.$white;
        v['$blue-darker'] = (0, _color2.default)(v.$blue).darken(0.05).toString();
        return v;
      };
      var theme = (0, _index.makeScopedTheme)('scopeName', makeDynamicTheme());
      var result = { $blue: 'pink', '$blue-darker': 'hsl(349.5, 100%, 83.3%)', $white: 'pink' };
      expect(theme.scopeName).toEqual(result);
      expect(theme.scopeName['$blue-darker']).toEqual(result['$blue-darker']);
    });
  });
  describe('createMakeTheme', function () {
    var themeListFunction = [(0, _index.toMakeTheme)((0, _theme.makeOriginal)({
      '$headings-font-family': '"Helvetica"'
    }))];
    var themeScopedListFunction = [(0, _index.toMakeTheme)((0, _theme.makeOriginal)({
      '$headings-font-family': '"Helvetica"'
    })), (0, _index.toMakeTheme)((0, _index.makeScopedTheme)('scopedTheme', {
      $color: 'blue'
    })), (0, _index.toMakeTheme)((0, _index.makeScopedTheme)('scopedThemeSecond', {
      '$bg-color': 'pink'
    }))];
    it('should have $headings-font-family equal to Helvetica', function () {
      var makeTheme = (0, _index2.default)(themeListFunction);
      expect(makeTheme()['$headings-font-family']).toBe('"Helvetica"');
    });

    it('should override $headings-font-family to equal Arial', function () {
      var makeTheme = (0, _index2.default)(themeListFunction);
      var modifiedTheme = makeTheme({
        '$headings-font-family': '"Arial"'
      });
      expect(modifiedTheme['$headings-font-family']).toBe('"Arial"');
    });
    it('should create a makeTheme based on a list of theme and scopedThemes', function () {
      var makeTheme = (0, _index2.default)(themeScopedListFunction);
      expect(makeTheme()['$headings-font-family']).toBe('"Helvetica"');
      expect(makeTheme().scopedTheme.$color).toBe('blue');
      expect(makeTheme().scopedThemeSecond['$bg-color']).toBe('pink');
    });
    it('should override theme and scoped theme variables', function () {
      var makeTheme = (0, _index2.default)(themeScopedListFunction);
      var modifiedTheme = makeTheme({
        '$headings-font-family': '"Arial"',
        scopedTheme: {
          $color: 'yellow'
        }
      });
      expect(modifiedTheme['$headings-font-family']).toBe('"Arial"');
      expect(modifiedTheme.scopedTheme.$color).toBe('yellow');
      expect(modifiedTheme.scopedThemeSecond['$bg-color']).not.toBe('orange');
    });
  });

  describe('toMakeTheme', function () {
    it('should treat theme like a NOT scoped theme', function () {
      var themeStartingWithVariable = { '$headings-font-family': 'Comic' };
      var makeThemeTestVariable = (0, _index.toMakeTheme)(themeStartingWithVariable);
      var themeStartingWithMetaData = { _name: 'name test' };
      var makeThemeTestMetaData = (0, _index.toMakeTheme)(themeStartingWithMetaData);
      expect(makeThemeTestVariable()['$headings-font-family']).toBe(themeStartingWithVariable['$headings-font-family']);
      expect(makeThemeTestMetaData()._name).toBe(themeStartingWithMetaData._name); // eslint-disable-line no-underscore-dangle
    });

    it('should create a makeTheme', function () {
      var theme = { '$headings-font-family': 'Comic' };
      var makeTheme = (0, _index.toMakeTheme)(theme);
      expect(makeTheme()['$headings-font-family']).toBe(theme['$headings-font-family']);
    });

    it('should override $headings-font-family variable to be equal to Arial', function () {
      var theme = { '$headings-font-family': 'Comic' };
      var makeThemeTest = (0, _index.toMakeTheme)(theme);
      var modifiedMakeThemeTest = makeThemeTest({
        '$headings-font-family': '"Arial"'
      });
      expect(modifiedMakeThemeTest['$headings-font-family']).toBe('"Arial"');
    });
    it('should create a makeTheme from a  scopedTheme', function () {
      var scopedTheme = { scopeName: { '$headings-font-family': 'Comic' } };
      var makeTheme = (0, _index.toMakeTheme)(scopedTheme);
      expect(makeTheme().scopeName['$headings-font-family']).toBe(scopedTheme.scopeName['$headings-font-family']);
    });

    it('should override $headings-font-family variable to be equal to Arial', function () {
      var scopedTheme = { scopeName: { '$headings-font-family': 'Comic' } };
      var makeTheme = (0, _index.toMakeTheme)(scopedTheme);
      var customTheme = makeTheme({
        scopeName: {
          '$headings-font-family': '"Arial"'
        }
      });
      expect(customTheme.scopeName['$headings-font-family']).toBe('"Arial"');
    });
  });
});
